==> haskell-hspec-2.10.9-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec
version:              2.10.9
visibility:           public
id:                   hspec-2.10.9-4sFPvLDpInD9EfozvBycsB
key:                  hspec-2.10.9-4sFPvLDpInD9EfozvBycsB
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <https://hspec.github.io/>.

category:             Testing
abi:                  95742ac992d35ecc85726b80ec0a54c3
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-2.10.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-2.10.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec
hs-libraries:         HShspec-2.10.9-4sFPvLDpInD9EfozvBycsB
depends:
    QuickCheck-2.14.3-DAn0LMacIHzJut6JKwFNdl base-4.15.1.0
    hspec-core-2.10.9-HyKSP1TZIT2C6Hp3VlYpQt
    hspec-discover-2.10.9-JwOddOaL1HPE8gr6X3MTEQ
    hspec-expectations-0.8.3-HK4ztKZ0KPHwaoXL9fa0R

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.10.9-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec
version:              2.10.9
visibility:           public
id:                   hspec-2.10.9-BH4qULbZrlnJSXuDrhUJHT
key:                  hspec-2.10.9-BH4qULbZrlnJSXuDrhUJHT
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <https://hspec.github.io/>.

category:             Testing
abi:                  b7e2d63f91f0a438dec2c4cf491e31d6
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hspec-2.10.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hspec-2.10.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec
hs-libraries:         HShspec-2.10.9-BH4qULbZrlnJSXuDrhUJHT
depends:
    QuickCheck-2.14.3-CQrltMH9CDMIjEPyrki3TE base-4.15.1.0
    hspec-core-2.10.9-I0JIqfkNpNSX0KU9NS2xn
    hspec-discover-2.10.9-7sT3oA4gi6uwpI1euUv1z
    hspec-expectations-0.8.3-GtEFyAkIxMfL6yE5lKnMix

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
